@@ -47,7 +47,14 @@ pass_info = click.make_pass_decorator(Info, ensure=True)
 
 
 def merge(a, b, path=None):
-    "merges dictionary b into dictionary a"
+    """
+    merges dictionary b into dictionary a
+
+    :param a: dictionary a
+    :param b: dictionary b
+    :param path: path to the current node
+    :return: merged dictionary
+    """
     if path is None: path = []
     for key in b:
         if key in a:
@@ -85,15 +92,13 @@ def cli(info: Info, verbose: int):
     info.verbose = verbose
 
 
-@cli.command()
-@click.argument('id', required=True)
+@cli.command(help="Get details for a specific project")
+@click.argument('id', required=True, help="The project id")
 @click.option('--url', default=KodexaPlatform.get_url(), help='The URL to the Kodexa server')
 @click.option('--token', default=KodexaPlatform.get_access_token(), help='Access token')
 @pass_info
 def project(_: Info, project_id: str, token: str, url: str):
-    """
-    Get all the details for a specific project
-    """
+
     client = KodexaClient(url=url, access_token=token)
     project_instance = client.get_project(project_id)
     print(f"Name: [bold]{project_instance.name}[/bold]")
@@ -109,16 +114,13 @@ def project(_: Info, project_id: str, token: str, url: str):
     project_instance.assistants.print_table()
 
 
-@cli.command()
-@click.argument('ref', required=True)
-@click.argument('path', required=True)
+@cli.command(help="Upload the contents of a file or directory to a document store")
+@click.argument('ref', required=True, help="The reference to the document store")
+@click.argument('path', required=True, help="The path to the file or directory to upload")
 @click.option('--url', default=KodexaPlatform.get_url(), help='The URL to the Kodexa server')
 @click.option('--token', default=KodexaPlatform.get_access_token(), help='Access token')
 @pass_info
 def upload(_: Info, ref: str, path: str, token: str, url: str):
-    """
-    Upload the contents of a file or directory to a Kodexa platform instance
-    """
 
     client = KodexaClient(url=url, access_token=token)
     document_store = client.get_object_by_ref('store', ref)
@@ -139,7 +141,7 @@ def upload(_: Info, ref: str, path: str, token: str, url: str):
         print(f"{ref} is not a document store")
 
 
-@cli.command()
+@cli.command(help="Deploy a component to a Kodexa platform instance from a file or stdin")
 @click.option('--org', help='The slug for the organization to deploy to', required=False)
 @click.option('--slug', help='Override the slug for component (only works for a single component)', required=False)
 @click.option('--version', help='Override the version for component (only works for a single component)',
@@ -154,9 +156,6 @@ def upload(_: Info, ref: str, path: str, token: str, url: str):
 @pass_info
 def deploy(_: Info, org: Optional[str], file: str, url: str, token: str, format=None, update: bool = False,
            version=None, overlay: Optional[str] = None, slug=None):
-    """
-    Deploy a component to a Kodexa platform instance from a file or stdin
-    """
 
     client = KodexaClient(access_token=token, url=url)
 
@@ -223,19 +222,17 @@ def deploy(_: Info, org: Optional[str], file: str, url: str, token: str, format=
     print("Deployed :tada:")
 
 
-@cli.command()
-@click.argument('execution_id', required=True)
+@cli.command(help="Get the logs for a specific execution")
+@click.argument('execution_id', required=True, help="The execution id to get the logs for")
 @click.option('--url', default=KodexaPlatform.get_url(), help='The URL to the Kodexa server')
 @click.option('--token', default=KodexaPlatform.get_access_token(), help='Access token')
 @pass_info
 def logs(_: Info, execution_id: str, url: str, token: str):
-    """
-    Get logs for an execution
-    """
     client = KodexaClient(url=url, access_token=token)
+    client.executions.get(execution_id).logs()
 
 
-@cli.command()
+@cli.command(help="List the instances of the component or entity type")
 @click.argument('object_type', required=True)
 @click.argument('ref', required=False)
 @click.option('--url', default=KodexaPlatform.get_url(), help='The URL to the Kodexa server')
@@ -249,9 +246,7 @@ def logs(_: Info, execution_id: str, url: str, token: str):
 @pass_info
 def get(_: Info, object_type: str, ref: Optional[str], url: str, token: str, query: str, path: str = None, format=None,
         page: int = 1, pagesize: int = 10, sort: str = None):
-    """
-    List the instance of the object type
-    """
+
     client = KodexaClient(url=url, access_token=token)
 
     from kodexa.platform.client import resolve_object_type
@@ -289,9 +284,9 @@ def get(_: Info, object_type: str, ref: Optional[str], url: str, token: str, que
             print(f"You must provide a ref to get a specific object")
 
 
-@cli.command()
-@click.argument('ref', required=True)
-@click.argument('query', default="*")
+@cli.command(help="Query the documents in a given document store")
+@click.argument('ref', required=True, help="The ref of the document store")
+@click.argument('query', default="*", help="The query to use")
 @click.option('--url', default=KodexaPlatform.get_url(), help='The URL to the Kodexa server')
 @click.option('--token', default=KodexaPlatform.get_access_token(), help='Access token')
 @click.option('--download/--no-download', default=False, help='Download the KDDB for the latest in the family')
@@ -302,9 +297,6 @@ def get(_: Info, object_type: str, ref: Optional[str], url: str, token: str, que
 @pass_info
 def query(_: Info, query: str, ref: str, url: str, token: str, download: bool, download_native: bool, page: int,
           pagesize: int, sort: None):
-    """
-    Query the documents in a given document store
-    """
     client = KodexaClient(url=url, access_token=token)
     from kodexa.platform.client import DocumentStoreEndpoint
 
@@ -316,34 +308,7 @@ def query(_: Info, query: str, ref: str, url: str, token: str, download: bool, d
         raise Exception("Unable to find document store with ref " + ref)
 
 
-@cli.command()
-@click.argument('ref', required=True)
-@click.argument('filter', default="*")
-@click.option('--url', default=KodexaPlatform.get_url(), help='The URL to the Kodexa server')
-@click.option('--token', default=KodexaPlatform.get_access_token(), help='Access token')
-@click.option('--download/--no-download', default=False, help='Download the KDDB for the latest in the family')
-@click.option('--download-native/--no-download-native', default=False, help='Download the native file for the family')
-@click.option('--page', default=1, help='Page number')
-@click.option('--pageSize', default=10, help='Page size')
-@click.option('--sort', default=None, help='Sort by ie. name:asc')
-@pass_info
-def query(_: Info, filter: str, ref: str, url: str, token: str, download: bool, download_native: bool, page: int,
-          pagesize: int, sort: None):
-    """
-    Query the documents in a given document store
-    """
-    client = KodexaClient(url=url, access_token=token)
-    from kodexa.platform.client import DocumentStoreEndpoint
-
-    document_store: DocumentStoreEndpoint = client.get_object_by_ref('store', ref)
-    if isinstance(document_store, DocumentStoreEndpoint):
-        results = document_store.filter(filter, page, pagesize, sort)
-
-    else:
-        raise Exception("Unable to find document store with ref " + ref)
-
-
-@cli.command()
+@cli.command(help="Export a project, and associated resources to a local zip file")
 @click.argument('project_id', required=True)
 @click.option('--url', default=KodexaPlatform.get_url(), help='The URL to the Kodexa server')
 @click.option('--token', default=KodexaPlatform.get_access_token(), help='Access token')
@@ -355,7 +320,7 @@ def export_project(_: Info, project_id: str, url: str, token: str, output: str):
     client.export_project(project_endpoint, output)
 
 
-@cli.command()
+@cli.command(help="Import a project, and associated resources from a local zip file")
 @click.argument('org_slug', required=True)
 @click.argument('path', required=True)
 @click.option('--url', default=KodexaPlatform.get_url(), help='The URL to the Kodexa server')
@@ -373,7 +338,7 @@ def import_project(_: Info, org_slug: str, url: str, token: str, path: str):
     print("Project imported")
 
 
-@cli.command()
+@cli.command(help="Send an event to an assistant")
 @click.argument('project_id', required=True)
 @click.argument('assistant_id', required=True)
 @click.option('--url', default=KodexaPlatform.get_url(), help='The URL to the Kodexa server')
@@ -382,8 +347,6 @@ def import_project(_: Info, org_slug: str, url: str, token: str, path: str):
 @click.option('--format', default=None, help='The format to use if from stdin (json, yaml)')
 @pass_info
 def send_event(_: Info, project_id: str, assistant_id: str, url: str, file: str, event_format: str, token: str):
-    """Send an event to an assistant
-    """
 
     client = KodexaClient(url, token)
 
@@ -413,7 +376,7 @@ def send_event(_: Info, project_id: str, assistant_id: str, url: str, file: str,
     print("Event sent :tada:")
 
 
-@cli.command()
+@cli.command(help="Get the details for the Kodexa instance we are logged into")
 @pass_info
 @click.option('--python/--no-python', default=False, help='Print out the header for a Python file')
 def platform(_: Info, python: bool):
@@ -436,7 +399,7 @@ def platform(_: Info, python: bool):
         print("Kodexa is not logged in")
 
 
-@cli.command()
+@cli.command(help="Delete the given resource")
 @click.argument('object_type')
 @click.argument('ref')
 @click.option('--url', default=KodexaPlatform.get_url(), help='The URL to the Kodexa server')
@@ -450,7 +413,7 @@ def delete(_: Info, object_type: str, ref: str, url: str, token: str):
     client.get_object_by_ref(object_type, ref).delete()
 
 
-@cli.command()
+@cli.command(help="Logs into the specified platform and store credentials locally")
 @pass_info
 def login(_: Info):
     """Logs into the specified platform environment using the email address and password provided,
@@ -472,23 +435,23 @@ def login(_: Info):
         KodexaPlatform.login(kodexa_url, username, password)
 
 
-@cli.command()
+@cli.command(help="Generate mkdocs documentation for components in kodexa.yml")
 @click.option('--path', default=os.getcwd(), help='Path to folder container kodexa.yml (defaults to current)')
 @pass_info
-def document(_: Info, path: str):
+def mkdocs(_: Info, path: str):
     metadata_obj = ExtensionHelper.load_metadata(path)
-    from kodexa.cli.documentation import generate_documentation
+    from kodexa_cli.documentation import generate_documentation
     generate_documentation(metadata_obj)
 
 
-@cli.command()
+@cli.command(help="Get the version of the CLI")
 @pass_info
 def version(_: Info):
     import pkg_resources
     print("Kodexa Version:", pkg_resources.get_distribution("kodexa").version)
 
 
-@cli.command()
+@cli.command(help="Package a kodexa.yml into a complete kodexa.json for deployment")
 @click.option('--path', default=os.getcwd(), help='Path to folder container kodexa.yml (defaults to current)')
 @click.option('--output', default=os.getcwd() + "/dist",
               help='Path to the output folder (defaults to dist under current)')
